Package: pathlinkR
Type: Package
Title: Analyze and interpret RNA-Seq results
Version: 1.9.5
Authors@R: c(
    person("Travis", "Blimkie", email = "travis.m.blimkie@gmail.com", role = "cre", comment = c(ORCID = "0000-0001-8778-8627")),
    person("Andy", "An", email = "andy@hancocklab.com", role = "aut")
    )
Description: pathlinkR is an R package designed to facilitate analysis
        of RNA-Seq results. Specifically, our aim with pathlinkR was to
        provide a number of tools which take a list of DE genes and
        perform different analyses on them, aiding with the
        interpretation of results. Functions are included to perform
        pathway enrichment, with muliplte databases supported, and
        tools for visualizing these results. Genes can also be used to
        create and plot protein-protein interaction networks, all from
        inside of R.
biocViews: GeneSetEnrichment, Network, Pathways, Reactome, RNASeq,
        NetworkEnrichment
BiocType: Software
BugReports: https://github.com/hancockinformatics/pathlinkR/issues
License: GPL-3 + file LICENSE
URL: https://github.com/hancockinformatics/pathlinkR
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Config/testthat/edition: 3
Depends: R (>= 4.5.0)
Imports: circlize, clusterProfiler, ComplexHeatmap, dplyr, fgsea,
        ggplot2, ggraph, ggrepel, grid, igraph, patchwork, purrr,
        sigora, stringr, tibble, tidygraph, tidyr, vegan, visNetwork
Suggests: AnnotationDbi, BiocStyle, biomaRt, covr, DESeq2, jsonlite,
        knitr, org.Hs.eg.db, rmarkdown, scales, testthat (>= 3.0.0)
LazyData: true
Config/pak/sysreqs: libcairo2-dev cmake libfontconfig1-dev
        libfreetype6-dev libglpk-dev make libicu-dev libpng-dev
        libuv1-dev libxml2-dev libssl-dev perl zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-07-05 00:26:54 UTC
RemoteUrl: https://github.com/bioc/pathlinkR
RemoteRef: HEAD
RemoteSha: 6a8671c8187cf6dc012df22f91066d1a8decba20
NeedsCompilation: no
Packaged: 2026-07-05 06:43:23 UTC; root
Author: Travis Blimkie [cre] (ORCID: <https://orcid.org/0000-0001-8778-8627>),
  Andy An [aut]
Maintainer: Travis Blimkie <travis.m.blimkie@gmail.com>
Built: R 4.6.1; ; 2026-07-05 06:45:42 UTC; unix
