# Generated by roxygen2: do not edit by hand

export(eruption)
export(getPathwayDistances)
export(pathnetCreate)
export(pathnetFoundation)
export(pathnetGGraph)
export(pathnetVisNetwork)
export(pathwayEnrichment)
export(pathwayPlots)
export(plotFoldChange)
export(ppiBuildNetwork)
export(ppiCleanNetwork)
export(ppiEnrichNetwork)
export(ppiExtractSubnetwork)
export(ppiPlotNetwork)
import(dplyr)
import(ggplot2)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,draw)
importFrom(circlize,colorRamp2)
importFrom(ggraph,geom_edge_link)
importFrom(ggraph,geom_node_label)
importFrom(ggraph,geom_node_point)
importFrom(ggraph,geom_node_text)
importFrom(ggraph,ggraph)
importFrom(ggraph,scale_edge_width)
importFrom(ggraph,set_graph_style)
importFrom(ggraph,theme_graph)
importFrom(ggrepel,geom_text_repel)
importFrom(grid,gpar)
importFrom(grid,grid.text)
importFrom(grid,unit)
importFrom(igraph,V)
importFrom(igraph,as.igraph)
importFrom(igraph,components)
importFrom(igraph,decompose)
importFrom(igraph,delete_vertices)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,induced_subgraph)
importFrom(igraph,neighborhood)
importFrom(igraph,shortest_paths)
importFrom(igraph,simplify)
importFrom(purrr,imap)
importFrom(purrr,imap_dfr)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_chr)
importFrom(purrr,possibly)
importFrom(purrr,reduce)
importFrom(stringr,str_count)
importFrom(stringr,str_length)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,str_wrap)
importFrom(tibble,column_to_rownames)
importFrom(tibble,enframe)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidygraph,activate)
importFrom(tidygraph,as_tbl_graph)
importFrom(tidygraph,centrality_betweenness)
importFrom(tidygraph,centrality_degree)
importFrom(tidygraph,centrality_hub)
importFrom(tidygraph,tbl_graph)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,separate_longer_delim)
importFrom(tidyr,separate_wider_delim)
importFrom(vegan,vegdist)
importFrom(visNetwork,visEdges)
importFrom(visNetwork,visExport)
importFrom(visNetwork,visIgraphLayout)
importFrom(visNetwork,visLegend)
importFrom(visNetwork,visNetwork)
importFrom(visNetwork,visNodes)
importFrom(visNetwork,visOptions)
